function varargout = ViewHistDialog(varargin)
% VIEWHISTDIALOG M-file for ViewHistDialog.fig
%      VIEWHISTDIALOG by itself, creates a new VIEWHISTDIALOG or raises the
%      existing singleton*.
%
%      H = VIEWHISTDIALOG returns the handle to a new VIEWHISTDIALOG or the handle to
%      the existing singleton*.
%
%      VIEWHISTDIALOG('CALLBACK',hObject,eventData,handles,...) calls the local
%      function named CALLBACK in VIEWHISTDIALOG.M with the given input arguments.
%
%      VIEWHISTDIALOG('Property','Value',...) creates a new VIEWHISTDIALOG or raises the
%      existing singleton*.  Starting from the left, property value pairs are
%      applied to the GUI before ViewHistDialog_OpeningFunction gets called.  An
%      unrecognized property name or invalid value makes property application
%      stop.  All inputs are passed to ViewHistDialog_OpeningFcn via varargin.
%
%      *See GUI Options on GUIDE's Tools menu.  Choose "GUI allows only one
%      instance to run (singleton)".
%
% See also: GUIDE, GUIDATA, GUIHANDLES

% Edit the above text to modify the response to help ViewHistDialog

% Last Modified by GUIDE v2.5 08-Aug-2005 09:54:20

% Begin initialization code - DO NOT EDIT
gui_Singleton = 1;
gui_State = struct('gui_Name',       mfilename, ...
                   'gui_Singleton',  gui_Singleton, ...
                   'gui_OpeningFcn', @ViewHistDialog_OpeningFcn, ...
                   'gui_OutputFcn',  @ViewHistDialog_OutputFcn, ...
                   'gui_LayoutFcn',  [] , ...
                   'gui_Callback',   []);
if nargin && ischar(varargin{1})
    gui_State.gui_Callback = str2func(varargin{1});
end

if nargout
    [varargout{1:nargout}] = gui_mainfcn(gui_State, varargin{:});
else
    gui_mainfcn(gui_State, varargin{:});
end
% End initialization code - DO NOT EDIT

% --- Executes just before ViewHistDialog is made visible.
function ViewHistDialog_OpeningFcn(hObject, eventdata, handles, varargin)
% This function has no output args, see OutputFcn.
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)
% varargin   command line arguments to ViewHistDialog (see VARARGIN)

handles.r                = varargin{1};

guidata(hObject, handles);

init_dialog(hObject, eventdata, handles, varargin);

% Choose default command line output for ViewHistDialog
% handles.output = 'Yes';

% Update handles structure
% guidata(hObject, handles);

% Insert custom Title and Text if specified by the user
% Hint: when choosing keywords, be sure they are not easily confused 
% with existing figure properties.  See the output of set(figure) for
% a list of figure properties.
% if(nargin > 3)
%     for index = 1:2:(nargin-3),
%         if nargin-3==index, break, end
%         switch lower(varargin{index})
%          case 'title'
%           set(hObject, 'Name', varargin{index+1});
%          case 'string'
%           set(handles.text1, 'String', varargin{index+1});
%         end
%     end
% end

% Determine the position of the dialog - centered on the callback figure
% if available, else, centered on the screen


% 
% FigPos=get(0,'DefaultFigurePosition');
% OldUnits = get(hObject, 'Units');
% set(hObject, 'Units', 'pixels');
% OldPos = get(hObject,'Position');
% FigWidth = OldPos(3);
% FigHeight = OldPos(4);
% if isempty(gcbf)
%     ScreenUnits=get(0,'Units');
%     set(0,'Units','pixels');
%     ScreenSize=get(0,'ScreenSize');
%     set(0,'Units',ScreenUnits);
% 
%     FigPos(1)=1/2*(ScreenSize(3)-FigWidth);
%     FigPos(2)=2/3*(ScreenSize(4)-FigHeight);
% else
%     GCBFOldUnits = get(gcbf,'Units');
%     set(gcbf,'Units','pixels');
%     GCBFPos = get(gcbf,'Position');
%     set(gcbf,'Units',GCBFOldUnits);
%     FigPos(1:2) = [(GCBFPos(1) + GCBFPos(3) / 2) - FigWidth / 2, ...
%                    (GCBFPos(2) + GCBFPos(4) / 2) - FigHeight / 2];
% end
% FigPos(3:4)=[FigWidth FigHeight];
% set(hObject, 'Position', FigPos);
% set(hObject, 'Units', OldUnits);
% 
% 
% 
% % Make the GUI modal
% set(handles.figure1,'WindowStyle','modal')




% UIWAIT makes ViewHistDialog wait for user response (see UIRESUME)
uiwait(handles.figure1);

% --- Outputs from this function are returned to the command line.
function varargout = ViewHistDialog_OutputFcn(hObject, eventdata, handles)
% varargout  cell array for returning output args (see VARARGOUT);
% hObject    handle to figure
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Get default command line output from handles structure


% The figure can be deleted now
delete(handles.figure1);

% --- Executes on button press in DoneButton.
function DoneButton_Callback(hObject, eventdata, handles)
% hObject    handle to DoneButton (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

close(handles.fighand);
% Use UIRESUME instead of delete because the OutputFcn needs
% to get the updated handles structure.
uiresume(handles.figure1);



function init_dialog(hObject, eventdata, handles, varargin)



set(handles.ComputePopup, 'Value', 1);

handles.fighand = figure(1);

r = handles.r;
c = max(size(r));

t = (r(2:c,:)-r(1:c-1,:));
t = [t(:,1)./sqrt(t(:,1).^2+t(:,2).^2),t(:,2)./sqrt(t(:,1).^2+t(:,2).^2)];
handles.dtheta = compute_theta(t);
handles.theta = compute_theta2(t);

guidata(hObject, handles);




DrawDataCall(hObject, eventdata, handles);


    
    
    % --- Executes on selection change in ColorMapPopupM.
function ComputePopup_Callback(hObject, eventdata, handles)
% hObject    handle to ColorMapPopupM (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    structure with handles and user data (see GUIDATA)

% Hints: contents = get(hObject,'String') returns ColorMapPopupM contents as cell array
%        contents{get(hObject,'Value')} returns selected item from ColorMapPopupM

DrawDataCall(hObject, eventdata, handles);
  

function ColorMapPopup_CreateFcn(hObject, eventdata, handles)
    ComputePopup_CreateFcn(hObject, eventdata, handles);

% --- Executes during object creation, after setting all properties.
function ComputePopup_CreateFcn(hObject, eventdata, handles)
% hObject    handle to ComputePopup (see GCBO)
% eventdata  reserved - to be defined in a future version of MATLAB
% handles    empty - handles not created until after all CreateFcns called

% Hint: popupmenu controls usually have a white background on Windows.
%       See ISPC and COMPUTER.
if ispc && isequal(get(hObject,'BackgroundColor'), get(0,'defaultUicontrolBackgroundColor'))
    set(hObject,'BackgroundColor','white');
end

set(hObject,'String',{'Theta','d Theta'});


function DrawDataCall(hObject, eventdata, handles)


figure(handles.fighand);
clf;

switch get(handles.ComputePopup,'Value')
    case 1
        hist(handles.theta,30);
        xlabel('\theta');
        ylabel('number');
    case 2
        hist(handles.dtheta,30);
        xlabel('d\theta');
        ylabel('number');
end;

